@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -51,10 +53,11 @@
 #include "platform.h"
 #include <string>
 #include <mapidefs.h>
-
+#include "freebusy.h"
 #include "icalmapi.h"
 
 #define M2IC_CENSOR_PRIVATE 0x0001
+#define M2IC_NO_VTIMEZONE 0x0002
 
 class ICALMAPI_API MapiToICal {
 public:
@@ -66,6 +69,7 @@ public:
 	virtual ~MapiToICal() {};
 
 	virtual HRESULT AddMessage(LPMESSAGE lpMessage, ULONG ulFlags) = 0;
+	virtual HRESULT AddBlocks(FBBlock_1 *lpsFBblk, LONG ulblocks, time_t tStart, time_t tEnd, std::string strOrganiser, std::string strUser, std::string strUID) = 0;
 	virtual HRESULT Finalize(ULONG ulFlags, std::string *strMethod, std::string *strIcal) = 0;
 	virtual HRESULT ResetObject() = 0;
 };
