@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -52,15 +54,16 @@
 #include "namedprops.h"
 #include "mapiguidext.h"
 #include <mapiguid.h>
+#include "icalmapi.h"
 
 /* MAPINAMEID strings are in UCS-2LE, so cannot be static initialized in linux
    We first define all strings, so we can use the nmStringNames[] lookup array
  */
-enum eIDNamedProps {
+enum ICALMAPI_API eIDNamedProps {
 	PROP_KEYWORDS = 0,
 // End of String names
-	PROP_MEETINGLOCATION, PROP_GOID, PROP_ISRECURRING, PROP_RID, PROP_OWNERCRITICALCHANGE, PROP_ATTENDEECRITICALCHANGE, PROP_MOZGEN, 
-	PROP_MOZLASTACK, PROP_MOZ_SNOOZE_SUFFIX, PROP_MOZSENDINVITE ,PROP_SENDASICAL, PROP_APPTSEQNR, PROP_APPTSEQTIME,
+	PROP_MEETINGLOCATION, PROP_GOID, PROP_ISRECURRING, PROP_CLEANID, PROP_OWNERCRITICALCHANGE, PROP_ATTENDEECRITICALCHANGE, PROP_OLDSTART, PROP_ISEXCEPTION, PROP_RECURSTARTTIME,
+	PROP_RECURENDTIME, PROP_MOZGEN, PROP_MOZLASTACK, PROP_MOZ_SNOOZE_SUFFIX, PROP_MOZSENDINVITE , PROP_APPTTSREF, PROP_FLDID, PROP_SENDASICAL, PROP_APPTSEQNR, PROP_APPTSEQTIME,
 	PROP_BUSYSTATUS, PROP_APPTAUXFLAGS, PROP_LOCATION, PROP_LABEL, PROP_APPTSTARTWHOLE, PROP_APPTENDWHOLE, PROP_APPTDURATION,
 	PROP_ALLDAYEVENT, PROP_RECURRENCESTATE, PROP_MEETINGSTATUS, PROP_RESPONSESTATUS, PROP_RECURRING, PROP_INTENDEDBUSYSTATUS,
 	PROP_RECURRINGBASE, PROP_REQUESTSENT, PROP_8230, PROP_RECURRENCETYPE, PROP_RECURRENCEPATTERN, PROP_TIMEZONEDATA, PROP_TIMEZONE,
@@ -74,15 +77,7 @@ enum eIDNamedProps {
 	SIZE_NAMEDPROPS
 };
 
-/* all strings of the string named properties (first part of enum)
-   these names must be converted to unicode before querying the actual id's
-*/
-extern const char* nmStringNames[];
-
-/* all named properties, string named and id named */
-extern MAPINAMEID mnNamedProps[];
-
 /* call this function to get the id's from the listed namedprops above */
-HRESULT HrLookupNames(IMAPIProp *lpPropObj, LPSPropTagArray *lppNamedProps);
+HRESULT ICALMAPI_API HrLookupNames(IMAPIProp *lpPropObj, LPSPropTagArray *lppNamedProps);
 
 #endif
