@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -66,7 +68,7 @@ class VMIMEToMAPI
 {
 public:
 	VMIMEToMAPI();
-	VMIMEToMAPI(LPADRBOOK lpAdrBook, ECLogger *newlogger, IMailUser *lpMailUser, delivery_options dopt);
+	VMIMEToMAPI(LPADRBOOK lpAdrBook, ECLogger *newlogger, delivery_options dopt);
 	virtual	~VMIMEToMAPI();
 
 	HRESULT convertVMIMEToMAPI(const string &input, IMessage *lpMessage);
@@ -77,22 +79,21 @@ private:
 	delivery_options m_dopt;
 	LPADRBOOK m_lpAdrBook;
 	IABContainer *m_lpDefaultDir;
-	IMailUser *m_lpMailUser;
 	BODYLEVEL bodyLevel;
 	ATTACHLEVEL attachLevel;
 	bool attach_signature;
 	bool m_bIsMsgInMsg;
 
 	HRESULT fillMAPIMail(vmime::message* VMMessage, IMessage *lpMessage);
-	HRESULT disectBody(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool onlyBody = false, bool filterDouble = false);
+	HRESULT disectBody(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool onlyBody = false, bool filterDouble = false, bool bAppendBody = false);
 
 	HRESULT handleHeaders(vmime::header* VMHeader, IMessage* lpMessage);
 	HRESULT handleRecipients(vmime::header* VMHeader, IMessage* lpMessage);
 	HRESULT modifyRecipientList(LPADRLIST lpRecipients, const vmime::addressList* lpVMAddressList, ULONG ulRecipType);
 	HRESULT modifyFromAddressBook(LPSPropValue *lppPropVals, ULONG *lpulValues, const char *email, const char *fullname, ULONG ulRecipType, LPSPropTagArray lpPropsList);
 
-	HRESULT handleTextpart(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage);
-	HRESULT handleHTMLTextpart(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage);
+	HRESULT handleTextpart(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool bAppendBody);
+	HRESULT handleHTMLTextpart(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool bAppendBody);
 	HRESULT handleAttachment(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage);
 	HRESULT handleMessageToMeProps(IMessage *lpMessage, LPADRLIST lpRecipients);
 	
