@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -106,7 +108,7 @@ public:
 	public:
 
 		embeddedObject(const contentHandler& data, const encoding& enc,
-		               const string& id, const mediaType& type, const string& name);
+		               const string& id, const mediaType& type, const string& name, const string& loc);
 
         ~embeddedObject();
         
@@ -129,6 +131,12 @@ public:
 		  */
 		const string& getId() const;
 
+		/** Return the location (URL) of this embedded object.
+		  *
+		  * @return object location url
+		  */
+		const string& getLocation() const;
+
 		/** Return the content type of data stored in
 		  * this embedded object.
 		  *
@@ -149,6 +157,7 @@ public:
 		string m_id;
 		mediaType m_type;
 		string m_name;
+		string m_loc;
 	};
 
 
@@ -218,11 +227,12 @@ public:
 	 * @param enc data encoding
 	 * @param type data type
 	 * @param id unique object identifier
+	 * @param loc optional location url of object
 	 * @param name filename of attachment
 	 * @return an unique object identifier used to identify the new
 	 * object among all other embedded objects
 	 */
-	const string addObject(const contentHandler& data, const encoding& enc, const mediaType& type, const string& id, const string& name = string());
+	const string addObject(const contentHandler& data, const encoding& enc, const mediaType& type, const string& id, const string& name = string(), const string& loc = string());
 
 private:
 
