@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1633,6 +1635,9 @@ public:
 #define DT_ORGANIZATION     ((ULONG) 0x00000004)
 #define DT_PRIVATE_DISTLIST ((ULONG) 0x00000005)
 #define DT_REMOTE_MAILUSER  ((ULONG) 0x00000006)
+#define DT_ROOM	            ((ULONG) 0x00000007)
+#define DT_EQUIPMENT        ((ULONG) 0x00000008)
+#define DT_SEC_DISTLIST     ((ULONG) 0x00000009)
 
 /*  For address book hierarchy tables */
 #define DT_MODIFIABLE       ((ULONG) 0x00010000)
@@ -1646,6 +1651,18 @@ public:
 #define DT_FOLDER_LINK      ((ULONG) 0x02000000)
 #define DT_FOLDER_SPECIAL   ((ULONG) 0x04000000)
 
+/* PR_DISPLAY_TYPE_EX flags */
+#define DTE_FLAG_REMOTE_VALID 0x80000000
+#define DTE_FLAG_ACL_CAPABLE  0x40000000
+#define DTE_MASK_REMOTE       0x0000ff00
+#define DTE_MASK_LOCAL        0x000000ff
+ 
+#define DTE_IS_REMOTE_VALID(v)	(!!((v) & DTE_FLAG_REMOTE_VALID))
+#define DTE_IS_ACL_CAPABLE(v)	(!!((v) & DTE_FLAG_ACL_CAPABLE))
+#define DTE_REMOTE(v)		(((v) & DTE_MASK_REMOTE) >> 8)
+#define DTE_LOCAL(v)		((v) & DTE_MASK_LOCAL)
+
+
 extern "C" {
 
 /*  Accelerator callback for DIALOG_SDI form of AB UI */
