@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -174,6 +176,7 @@ template<>
 
 /* darn, no sane place because of depend include on mapidefs.h */
 bool operator ==(SBinary a, SBinary b);
+bool operator <(SBinary a, SBinary b);
 
 #define CLIENT_ADMIN_SOCKET "file:///var/run/zarafa"
 char* GetServerUnixSocket(char* szPreferred = NULL);
@@ -213,10 +216,10 @@ HRESULT HrConvertFromWString(const ucs2string &wstrInput, const std::string &str
 HRESULT HrEscapeHTML(ucs2string &wstrInput, std::string &strOutput);
 HRESULT HrToQuotedPrintable1252(std::string &input, std::string *output, bool header = true);
 
-HRESULT HrNewMailNotification(IMsgStore* lpMDB, IMessage* lpMessage, ECLogger* lpLogger = NULL);
+HRESULT HrNewMailNotification(IMsgStore* lpMDB, IMessage* lpMessage);
 HRESULT HrCreateEmailSearchKey(char* lpszEmailType, char* lpszEmail, ULONG* cb, LPBYTE* lppByte);
 
-HRESULT DoSentMail(IMAPISession *lpSession, ULONG ulMessage, IMessage *lpMessage);
+HRESULT DoSentMail(IMAPISession *lpSession, IMsgStore *lpMDB, ULONG ulFlags, IMessage *lpMessage);
 
 HRESULT TestRestriction(LPSRestriction lpCondition, ULONG cValues, LPSPropValue lpPropVals, ULONG ulLevel = 0);
 HRESULT TestRestriction(LPSRestriction lpCondition, IMAPIProp *lpMessage, ULONG ulLevel = 0);
@@ -229,6 +232,7 @@ HRESULT DeleteProfileTemp(char *szProfName);
 HRESULT OpenSubFolder(LPMDB lpMDB, char *folder, char psep, ECLogger *lpLogger, bool blIsPublic, bool bCreateFolder, LPMAPIFOLDER *lppSubFolder);
 HRESULT FindFolder(LPMAPITABLE lpTable, const char *folder, LPSPropValue *lppFolderProp);
 
+HRESULT HrOpenUserMsgStore(LPMAPISESSION lpSession, char *lpszUser, LPMDB *lppStore);
 
 HRESULT HrGetPropTags(char **names, IMAPIProp *lpProp, LPSPropTagArray *lppPropTagArray);
 
@@ -277,6 +281,9 @@ private:
 #define PROPMAP_NAMED_ID(name,type,guid,id) ULONG PROP_##name; __propmap.AddProp(&PROP_##name, type, ECPropMapEntry(guid, id));
 #define PROPMAP_INIT(lpObject) hr = __propmap.Resolve(lpObject); if(hr != hrSuccess) goto exit;
 
+#define PROPMAP_DEF_NAMED_ID(name) ULONG PROP_##name;
+#define PROPMAP_INIT_NAMED_ID(name,type,guid,id) __propmap.AddProp(&PROP_##name, type, ECPropMapEntry(guid, id));
+
 
 // Determine the size of an array
 template <typename T, unsigned N>
