@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -70,7 +72,7 @@ public:
 
 	HRESULT HrEnableTLS();
 
-	HRESULT HrReadLine(char *szBuffer, ULONG ulBufSize);
+	HRESULT HrGets(char *szBuffer, ULONG ulBufSize, ULONG *lpulRead);
 	HRESULT HrReadLine(std::string * strBuffer);
 	HRESULT HrWriteString(char * szBuffer);
 	HRESULT HrWriteString(const std::string & strBuffer);
@@ -81,6 +83,9 @@ public:
 
 	HRESULT HrSelect(int seconds);
 
+	void SetIPAddress(char *szIPAddress);
+	std::string GetIPAddress();
+		
 	bool UsingSsl();
 	bool sslctx();
 
@@ -91,9 +96,10 @@ private:
 	int fd;
 	SSL *lpSSL;
 	static SSL_CTX *lpCTX;
+	string strIP;
 
-	char *fd_gets(char *buf, int len);
-	char *SSL_gets(char *buf, int len);
+	char *fd_gets(char *buf, int *lpulLen);
+	char *SSL_gets(char *buf, int *lpulLen);
 };
 
 /* helpers to open socket */
