@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -89,14 +91,54 @@
 #define RIGHT_DELETED				0x04
 #define RIGHT_AUTOUPDATE_DENIED		0x08
 
-// Different types of userobjects
-enum userobject_type_t {
-	USEROBJECT_TYPE_USER = 1,
-	USEROBJECT_TYPE_GROUP = 2,
-	USEROBJECT_TYPE_CONTACT = 3,
-	USEROBJECT_TYPE_COMPANY = 4,
-	USEROBJECT_TYPE_NONACTIVE = 5,
-	USEROBJECT_TYPE_ADDRESSLIST = 6
+#define OBJECTCLASS(__type, __class) \
+	( (((__type) << 16) | ((__class) & 0xffff)) )
+#define OBJECTCLASS_CLASSTYPE(__class) \
+	( ((__class) & 0xffff0000) )
+#define OBJECTCLASS_TYPE(__class) \
+	( (objecttype_t)(((__class) >> 16) & 0xffff) )
+#define OBJECTCLASS_ISTYPE(__class) \
+	( (((__class) & 0xffff) == 0) && (((__class) >> 16) != 0) )
+#define OBJECTCLASS_FIELD_COMPARE(__left, __right) \
+	( !(__left) || !(__right) || (__left) == (__right) )
+#define OBJECTCLASS_COMPARE(__left, __right) \
+	( OBJECTCLASS_FIELD_COMPARE(OBJECTCLASS_TYPE(__left), OBJECTCLASS_TYPE(__right)) && \
+	  OBJECTCLASS_FIELD_COMPARE((__left) & 0xffff, (__right) & 0xffff) )
+#define OBJECTCLASS_COMPARE_SQL(__column, __objclass) \
+	string((!(__objclass)) ? \
+			"TRUE" : \
+			((__objclass) & 0xffff) ? \
+				__column " = " + stringify(__objclass) : \
+				"(" __column " & 0xffff0000) = " + stringify((__objclass) & 0xffff0000))
+
+enum objecttype_t {
+	OBJECTTYPE_UNKNOWN		= 0,
+	OBJECTTYPE_MAILUSER		= 1,
+	OBJECTTYPE_DISTLIST		= 3,
+	OBJECTTYPE_CONTAINER	= 4
+};
+
+enum objectclass_t {
+	OBJECTCLASS_UNKNOWN		= OBJECTCLASS(OBJECTTYPE_UNKNOWN, 0),
+
+	/* All User (active and nonactive) objectclasses */
+	OBJECTCLASS_USER		= OBJECTCLASS(OBJECTTYPE_MAILUSER, 0),
+	ACTIVE_USER				= OBJECTCLASS(OBJECTTYPE_MAILUSER, 1),
+	NONACTIVE_USER			= OBJECTCLASS(OBJECTTYPE_MAILUSER, 2),
+	NONACTIVE_ROOM			= OBJECTCLASS(OBJECTTYPE_MAILUSER, 3),
+	NONACTIVE_EQUIPMENT		= OBJECTCLASS(OBJECTTYPE_MAILUSER, 4),
+	NONACTIVE_CONTACT		= OBJECTCLASS(OBJECTTYPE_MAILUSER, 5),
+
+	/* All distribution lists */
+	OBJECTCLASS_DISTLIST	= OBJECTCLASS(OBJECTTYPE_DISTLIST, 0),
+	DISTLIST_GROUP			= OBJECTCLASS(OBJECTTYPE_DISTLIST, 1),
+	DISTLIST_SECURITY		= OBJECTCLASS(OBJECTTYPE_DISTLIST, 2),
+	DISTLIST_DYNAMIC		= OBJECTCLASS(OBJECTTYPE_DISTLIST, 3),
+
+	/* All container objects */
+	OBJECTCLASS_CONTAINER	= OBJECTCLASS(OBJECTTYPE_CONTAINER, 0),
+	CONTAINER_COMPANY		= OBJECTCLASS(OBJECTTYPE_CONTAINER, 1),
+	CONTAINER_ADDRESSLIST	= OBJECTCLASS(OBJECTTYPE_CONTAINER, 2)
 };
 
 enum userobject_relation_t {
@@ -129,21 +171,50 @@ typedef struct _sECServerNameList
 	char**			lpszaServer;
 } ECSVRNAMELIST, *LPECSVRNAMELIST;
 
+typedef struct _sPropmapEntry {
+	unsigned int	ulPropId;
+	char*			lpszValue;
+} SPROPMAPENTRY, *LPSPROPMAPENTRY;
+
+typedef struct _sPropmap {
+	unsigned int		cEntries;
+	LPSPROPMAPENTRY		lpEntries;
+} SPROPMAP, *LPSPROPMAP;
+
+typedef struct _sMVPropmapEntry {
+	unsigned int	ulPropId;
+	int				cValues;
+	char**			lpszValues;
+} MVPROPMAPENTRY, *LPMVPROPMAPENTRY;
+
+typedef struct _sMVPropmap {
+	unsigned int		cEntries;
+	LPMVPROPMAPENTRY	lpEntries;
+} MVPROPMAP, *LPMVPROPMAP;
+
 typedef struct _sECUser {
 	char*			lpszUsername;	// username@companyname
 	char*			lpszPassword;
 	char*			lpszFullEmail;
 	char*			lpszFullName;
 	char*			lpszServername;
-	unsigned int	ulIsNonActive;
+	unsigned int	ulIsNonActive;	// See objectclass_t, "misuse" of existing variable
 	unsigned int	ulIsAdmin;		// See userobject_admin_level_t
+	unsigned int	ulIsABHidden;	// Is user hidden from address book
+	unsigned int	ulCapacity;		// Resource capacity
+	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
+	MVPROPMAP		sMVPropmap;		// Extra anonymous MV properties for addressbook
 	ECENTRYID		sUserId;
 } ECUSER, *LPECUSER;
 
 typedef struct _sECGroup {
 	char*			lpszGroupname; // groupname@companyname
 	char*			lpszFullname;
+	char*			lpszFullEmail;
 	ECENTRYID		sGroupId;
+	unsigned int	ulIsABHidden;	// Is group hidden from address book
+	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
+	MVPROPMAP		sMVPropmap;		// Extra anonymous MV properties for addressbook
 }ECGROUP, *LPECGROUP;
 
 typedef struct _sECCompany {
@@ -151,6 +222,9 @@ typedef struct _sECCompany {
 	char*			lpszCompanyname;
 	char*			lpszServername;
 	ECENTRYID		sCompanyId;
+	unsigned int	ulIsABHidden;	// Is company hidden from address book
+	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
+	MVPROPMAP		sMVPropmap;		// Extra anonymous MV properties for addressbook
 } ECCOMPANY, *LPECCOMPANY;
 
 typedef struct _sECPermission {
@@ -164,7 +238,7 @@ typedef struct _sECUserObject {
 	char*				lpszName;		// Fullname or fallback on username/groupname (name@companyname)
 	unsigned int		ulId;			// User or group id
 	ECENTRYID			sId;			// User or group eid
-	userobject_type_t	type;			// User type (user, group, etc...)
+	objectclass_t		type;			// User type (user, group, etc...)
 }ECUSEROBJECT, *LPECUSEROBJECT;
 
 typedef struct _sECQuota {
@@ -194,22 +268,12 @@ typedef struct _sECServerList {
 	LPECSERVER		lpsaServer;
 }ECSERVERLIST, *LPECSERVERLIST;
 
-// Getuserobjectlist
-#define ECUSEROBJECT_LIST_USERS_ACTIVE		0x00000001
-#define ECUSEROBJECT_LIST_USERS_NONACTIVE	0x00000002
-#define ECUSEROBJECT_LIST_USERS			ECUSEROBJECT_LIST_USERS_ACTIVE | ECUSEROBJECT_LIST_USERS_NONACTIVE
-#define ECUSEROBJECT_LIST_GROUP			0x00000004
-#define ECUSEROBJECT_LIST_COMPANY		0x00000008
-
 // Flags for ns__submitMessage
 #define EC_SUBMIT_LOCAL			0x00000000
 #define EC_SUBMIT_MASTER		0x00000001
 
 #define EC_SUBMIT_DOSENTMAIL	0x00000002
 
-// Behavior flags
-#define EC_BF_ABEID_V1			0x00000001
-
 // GetServerDetails
 #define EC_SERVERDETAIL_NO_NAME			0x00000001
 #define EC_SERVERDETAIL_FILEPATH		0x00000002
