@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -54,6 +56,10 @@
 #include <stdarg.h>
 #include "ECConfig.h"
 
+#ifndef __LIKE_PRINTF
+#define __LIKE_PRINTF(_fmt, _va)
+#endif
+
 #define EC_LOGLEVEL_NONE	0
 #define EC_LOGLEVEL_FATAL	1
 #define EC_LOGLEVEL_ERROR	2
@@ -65,6 +71,10 @@
 #define _LOG_BUFSIZE		10240
 #define _LOG_TSSIZE			64
 
+#define LOG_DEBUG(_plog,_msg,...) if ((_plog)->Log(EC_LOGLEVEL_DEBUG)) (_plog)->Log(EC_LOGLEVEL_DEBUG, _msg, ##__VA_ARGS__)
+
+enum logprefix { LP_NONE, LP_TID, LP_PID };
+
 class ECLogger {
 protected:
 	char* MakeTimestamp();
@@ -72,6 +82,7 @@ protected:
 	int max_loglevel;
 	char *msgbuffer;
 	char timestring[_LOG_TSSIZE];
+	logprefix prefix;
 
 public:
 	ECLogger(int max_ll);
@@ -79,10 +90,12 @@ public:
 
 	bool Log(int loglevel);
 	void SetLoglevel(int max_ll);
+	void SetLogprefix(logprefix lp);
 
 	virtual void Reset() = 0;
+	virtual int GetFileDescriptor();
 	virtual void Log(int loglevel, const std::string &message) = 0;
-	virtual void Log(int loglevel, const char *format, ...) = 0;
+	virtual void Log(int loglevel, const char *format, ...) __LIKE_PRINTF(3, 4) = 0;
 };
 
 
@@ -94,7 +107,7 @@ public:
 
 	virtual void Reset();
 	virtual void Log(int loglevel, const std::string &message);
-	virtual void Log(int Loglevel, const char *format, ...);
+	virtual void Log(int Loglevel, const char *format, ...) __LIKE_PRINTF(3, 4);
 };
 
 /* File logger. Use "-" for stderr logging */
@@ -115,7 +128,9 @@ public:
 
 	virtual void Reset();
 	virtual void Log(int loglevel, const std::string &message);
-	virtual void Log(int loglevel, const char *format, ...);
+	virtual void Log(int loglevel, const char *format, ...) __LIKE_PRINTF(3, 4);
+
+	int GetFileDescriptor();
 };
 
 /*	Linux syslog logger */
@@ -129,12 +144,30 @@ public:
 
 	virtual void Reset();
 	virtual void Log(int loglevel, const std::string &message);
-	virtual void Log(int loglevel, const char *format, ...);
+	virtual void Log(int loglevel, const char *format, ...) __LIKE_PRINTF(3, 4);
 };
 
-/* Windows eventlog logger */
+
+/*  */
+class ECLogger_Pipe : public ECLogger {
+private:
+	int m_fd;
+
+public:
+	ECLogger_Pipe(int fd);
+	~ECLogger_Pipe();
+
+	virtual void Reset();
+	virtual void Log(int loglevel, const std::string &message);
+	virtual void Log(int loglevel, const char *format, ...) __LIKE_PRINTF(3, 4);
+
+	int GetFileDescriptor();
+};
+
+ECLogger* StartLoggerProcess(ECConfig *lpConfig, ECLogger *lpFileLogger);
 
 ECLogger* CreateLogger(ECConfig *config, char *argv0, const char *lpszServiceName);
+int DeleteLogger(ECLogger *lpLogger);
 void LogConfigErrors(ECConfig *lpConfig, ECLogger *lpLogger);
 
 #endif
