@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -117,6 +119,7 @@
 #define PR_EC_STATS_SESSION_PEER_PID	PROP_TAG(PT_LONG,		PR_EC_BASE+0x4e)
 #define PR_EC_STATS_SESSION_CLIENT_VERSION	PROP_TAG(PT_STRING8,	PR_EC_BASE+0x4f)
 #define PR_EC_STATS_SESSION_CLIENT_APPLICATION PROP_TAG(PT_STRING8, PR_EC_BASE+0x50)
+#define PR_EC_STATS_SESSION_REQUESTS	PROP_TAG(PT_LONG, 		PR_EC_BASE+0x51)
 
 #define PR_EC_OUTOFOFFICE				PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0x60)
 #define PR_EC_OUTOFOFFICE_MSG			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x61)
@@ -152,11 +155,17 @@
 #define PR_EC_SENDAS_USER_ENTRYIDS		PROP_TAG(PT_MV_BINARY,	PR_EC_BASE+0x83)
 
 // addressbook ADS legacyExchange DN
-#define PR_EC_EXCHANGE_DN			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x88)
+#define PR_EC_EXCHANGE_DN				PROP_TAG(PT_STRING8,PR_EC_BASE+0x88)
+
+// notification based syncronization
+#define PR_EC_CHANGE_ADVISOR			PROP_TAG(PT_OBJECT, PR_EC_BASE+0x89)
+#define PR_EC_CHANGE_ONL_STATE			PROP_TAG(PT_BINARY, PR_EC_BASE+0x8A)
+#define PR_EC_CHANGE_OFFL_STATE			PROP_TAG(PT_BINARY, PR_EC_BASE+0x8B)
 
 // server path to home server of a user
 #define PR_EC_SERVERPATH				PROP_TAG(PT_STRING8,	PR_EC_BASE+0xC0)
 #define PR_EC_HOMESERVER_NAME			PROP_TAG(PT_STRING8,	PR_EC_BASE+0xC1)
+#define PR_EC_SERVER_UID				PROP_TAG(PT_BINARY,		PR_EC_BASE+0xC2)
 
 #define PR_EC_SEARCHFOLDER_STATUS		PROP_TAG(PT_LONG,	PR_EC_BASE+0x90)
 
@@ -168,9 +177,10 @@
 
 
 // Properties for IMailUsers
-#define PR_EC_NONACTIVE					PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0xB0) // Maps to 'ulIsNonAcive' in ECUser
+#define PR_EC_NONACTIVE					PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0xB0)
 #define PR_EC_ADMINISTRATOR				PROP_TAG(PT_LONG,		PR_EC_BASE+0xB1) // Maps to 'ulIsAdmin' in ECUser
 
+#define PR_EC_MGR_ORG_ENTRYID    		PROP_TAG(PT_BINARY,	    PR_EC_BASE+0xB2)  //this property will store original entry id of a migrated message
 
 // Flags for PR_EC_FLAGS
 #define EC_PROFILE_FLAGS_NO_NOTIFICATIONS		0x0000001
