@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -48,13 +50,37 @@
 #ifndef __UNIXUTIL_H
 #define __UNIXUTIL_H
 
+
+#include <sys/resource.h>
+
 #include "ECLogger.h"
 #include "ECConfig.h"
 
+struct popen_rlimit {
+	int resource;
+	struct rlimit limit;
+};
+
+struct popen_rlimit_array {
+	unsigned int cValues;
+	struct popen_rlimit sLimit[1];
+};
+
+#define sized_popen_rlimit_array(_climit, _name) \
+struct _popen_rlimit_array_ ## _name \
+{ \
+	unsigned int cValues; \
+	struct popen_rlimit sLimit[_climit]; \
+} _name
+
 int unix_runas(ECConfig *lpConfig, ECLogger *lpLogger);
 int unix_chown(const char *filename, const char *username, const char *groupname);
 int unix_create_pidfile(char *argv0, ECConfig *lpConfig, ECLogger *lpLogger, bool bForce = true);
 int unix_daemonize(ECConfig *lpConfig, ECLogger *lpLogger);
-int unix_popen_rw(const char *command, int *infp, int *outfp);
+int unix_fork_function(void*(func)(void*), void *param);
+pid_t unix_popen_rw(ECLogger *lpLogger, const char *command, int *infp, int *outfp, popen_rlimit_array *lpLimits, const char **env);
+bool unix_system(ECLogger *lpLogger, const char *szLogName, const char *command, const char **env);
+
+
 
 #endif
