@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -55,11 +57,6 @@
 
 class Util {
 public:
-	static std::string GetServerNameFromPath(const char *szPath);
-	static std::string GetServerPortFromPath(const char *szPath);
-	static std::string GetServerTypeFromPath(const char *szPath);
-	static std::string ServerNamePortToURL(const char *lpszType, const char *lpszServerName, const char *lpszServerPort);
-
 	static HRESULT	HrAddToPropertyArray(LPSPropValue lpSrc, ULONG cValues, LPSPropValue lpAdd, LPSPropValue *lppDest, ULONG *cDestValues);
 	static HRESULT	HrMergePropertyArrays(LPSPropValue lpSrc, ULONG cValues, LPSPropValue lpAdds, ULONG cAddValues, LPSPropValue *lppDest, ULONG *cDestValues);
 
@@ -75,8 +72,8 @@ public:
 	static HRESULT	HrCopySRowSet(LPSRowSet lpDest, LPSRowSet lpSrc, void *lpBase);
 	static HRESULT	HrCopySRow(LPSRow lpDest, LPSRow lpSrc, void *lpBase);
 
-	static HRESULT	HrCopyBinary(ULONG ulSize, LPBYTE lpSrc, ULONG *lpulDestSize, LPBYTE *lppDest);
-	static HRESULT	HrCopyEntryId(ULONG ulSize, LPENTRYID lpSrc, ULONG *lpulDestSize, LPENTRYID* lppDest);
+	static HRESULT	HrCopyBinary(ULONG ulSize, LPBYTE lpSrc, ULONG *lpulDestSize, LPBYTE *lppDest, LPVOID lpBase = NULL);
+	static HRESULT	HrCopyEntryId(ULONG ulSize, LPENTRYID lpSrc, ULONG *lpulDestSize, LPENTRYID* lppDest, LPVOID lpBase = NULL);
 
 	static HRESULT	CompareProp(LPSPropValue lpProp1, LPSPropValue lpProp2, int* lpCompareResult);
 	static unsigned int PropSize(LPSPropValue lpProp);
@@ -100,10 +97,8 @@ public:
 
 	static HRESULT HrConvertUnicodeToString8(ULONG cValues, LPSPropValue lpPropArrayIn, LPSPropValue* lppPropArrayOut);
 
-	static std::string bin2hex(ULONG inLength, LPBYTE input);
 	static HRESULT bin2hex(ULONG inLength, LPBYTE input, char **output, void *parent = NULL);
-	static HRESULT hex2bin(char *input, size_t len, ULONG *outLength, LPBYTE *output, void *parent = NULL);
-	static HRESULT hex2bin(const std::string &input, std::string *output);
+	static HRESULT hex2bin(const char *input, size_t len, ULONG *outLength, LPBYTE *output, void *parent = NULL);
 
 	static HRESULT FileLFtoCRLF(FILE *fin, FILE** fout);
 	static void BufferLFtoCRLF(size_t size, const char *input, char *output, size_t *outsize);
@@ -137,10 +132,6 @@ public:
 	static HRESULT HrGetQuotaStatus(IMsgStore *lpMsgStore, LPECQUOTA lpsQuota, LPECQUOTASTATUS *lppsQuotaStatus);
 
 	static HRESULT HrDeleteResidualProps(LPMESSAGE lpDestMsg, LPMESSAGE lpSourceMsg, LPSPropTagArray lpsValidProps);
-
-private:
-	static unsigned char x2b(char c);	// hex2bin helper
-	
 };
 
 #define RTF_TAG_TYPE_TEXT	0x0000
