@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -59,6 +61,10 @@
 #define PR_ATTACH_CONTENT_ID (PROP_TAG(PT_TSTRING,0x3712))
 #endif
 
+#ifndef PR_ATTACH_CONTENT_LOCATION
+#define PR_ATTACH_CONTENT_LOCATION (PROP_TAG(PT_TSTRING,0x3713))
+#endif
+
 #define RETURN_PROP_CASE(pt) case PROP_ID(pt): return((#pt))
 
 #ifndef PR_USER_X509_CERTIFICATE
@@ -371,9 +377,104 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 #define PR_LAST_VERB_EXECUTED			PROP_TAG(PT_LONG, 0x1081)
 #define PR_LAST_VERB_EXECUTION_TIME		PROP_TAG(PT_SYSTIME, 0x1082)
 
-#ifndef EXCHIVERB_FORWARD
-#define EXCHIVERB_FORWARD		104
-#endif
+/* defines from [MS-OXOMSG].pdf, except they're really decimal, and not hexadecimal. */
+#define NOTEIVERB_OPEN				0	// Open
+#define NOTEIVERB_REPLYTOSENDER		102	// ReplyToSender
+#define NOTEIVERB_REPLYTOALL		103	// ReplyToAll
+#define NOTEIVERB_FORWARD			104	// Forward
+#define NOTEIVERB_PRINT				105	// Print
+#define NOTEIVERB_SAVEAS			106	// Save as
+#define NOTEIVERB_REPLYTOFOLDER		108	// ReplyToFolder
+#define NOTEIVERB_SAVE				500	// Save
+#define NOTEIVERB_PROPERTIES		510	// properties
+#define NOTEIVERB_FOLLOWUP			511	// Followup
+#define NOTEIVERB_ACCEPT			512	// Accept
+#define NOTEIVERB_TENTATIVE			513	// Tentative
+#define NOTEIVERB_REJECT			514	// Reject
+#define NOTEIVERB_DECLINE			515	// Decline
+#define NOTEIVERB_INVITE			516	// Invite
+#define NOTEIVERB_UPDATE			517	// Update
+#define NOTEIVERB_CANCEL			518	// Cancel
+#define NOTEIVERB_SILENTINVITE		519	// SilentInvite
+#define NOTEIVERB_SILENTCANCEL		520	// SilentCancel
+#define NOTEIVERB_RECALL_MESSAGE	521	// RecallMessage
+#define NOTEIVERB_FORWARD_RESPONSE	522	// ForwardResponse
+
+#define ICON_FOLDER_DEFAULT			0xFFFFFFFF	// Different from documentation: -1 is dependant on folder the item is in
+
+/* defines from [MS-OXOMSG].pdf for email icons */
+#define ICON_MAIL_READ				0x00000100	// Read mail
+#define ICON_MAIL_UNREAD			0x00000101	// Unread mail
+#define ICON_MAIL_SUBMITTED			0x00000102	// Submitted mail
+#define ICON_MAIL_UNSENT			0x00000103	// Unsent mail
+#define ICON_MAIL_RECEIPT			0x00000104	// Receipt mail
+#define ICON_MAIL_REPLIED			0x00000105	// Replied mail
+#define ICON_MAIL_FORWARDED			0x00000106	// Forwarded mail
+#define ICON_MAIL_REMOTE			0x00000107	// Remote mail
+#define ICON_MAIL_DELIVERY_RECEIPT	0x00000108	// Delivery receipt 
+#define ICON_MAIL_READ_RECEIPT		0x00000109	// Read receipt 
+#define ICON_MAIL_NONDELIVERY_RECEIPT 0x0000010A	// Non-delivery Report
+#define ICON_MAIL_NONREAD_RECEIPT	0x0000010B	// Non-read receipt
+#define ICON_MAIL_RECALL_S			0x0000010C	// Recall_S mails
+#define ICON_MAIL_RECALL_F			0x0000010D	// Recall_F mail
+#define ICON_MAIL_TRACKING			0x0000010E	// Tracking mail
+#define ICON_MAIL_OOF				0x0000011B	// Out of Office mail
+#define ICON_MAIL_RECALL			0x0000011C	// Recall mail
+#define ICON_MAIL_TRACKED			0x00000130	// Tracked mail
+
+/* defines from [MS-OXOCNTC].pdf for contact icons, but nothing useful was there */
+#define ICON_CONTACT_USER			0x00000200		// Contact
+#define ICON_CONTACT_ADDRESSBOOK	0x00000201		// Contact that was imported from GAB
+#define ICON_CONTACT_DISTLIST		0x00000202		// Distribution list
+
+/* defines from [MS-OXONOTE].pdf for note icons*/
+#define ICON_NOTE					0x00000300		// Note, only documented in pdf
+#define ICON_NOTE_BLUE				0x00000300
+#define ICON_NOTE_GREEN				0x00000301
+#define ICON_NOTE_PINK				0x00000302
+#define ICON_NOTE_YELLOW			0x00000303
+#define ICON_NOTE_WHITE				0x00000304
+
+/* defines from [MS-OXOCAL].pdf for calendar */
+#define ICON_APPT_APPOINTMENT		0x00000400		// Single-instance appointment on Appointment object  
+#define ICON_APPT_RECURRING			0x00000401		// Recurring appointment on Appointment object  
+#define ICON_APPT_MEETING_SINGLE	0x00000402		// Single-instance meeting on Meeting object  
+#define ICON_APPT_MEETING_RECURRING	0x00000403		// Recurring meeting on Meeting object  
+#define ICON_APPT_MEETING_REQUEST	0x00000404		// meeting request/full update on Meeting Request object, Meeting Update object 
+#define ICON_APPT_MEETING_ACCEPT	0x00000405		// Accept on Meeting Response object  
+#define ICON_APPT_MEETING_DECLINE	0x00000406		// Decline on Meeting Response object  
+#define ICON_APPT_MEETING_TENTATIVE	0x00000407		// Tentatively accept on Meeting Response object  
+#define ICON_APPT_MEETING_CANCEL	0x00000408		// Cancellation on Meeting Cancellation object  
+#define ICON_APPT_MEETING_UPDATE	0x00000409		// informational update  on Meeting Update object  
+#define ICON_APPT_MEETING_FORWARD	0x0000040b		// Forward notification on Meeting Forward Notification object  
+
+/* defines from [MS-OXOTASK].pdf for task icons */
+#define ICON_TASK_NORMAL			0x00000500		// None of the other conditions apply
+#define ICON_TASK_RECURRING			0x00000501		// The Task object has not been assigned and is a recurring task
+#define ICON_TASK_ASSIGNEE			0x00000502		// The Task object is the task assignee's copy of the Task object
+#define ICON_TASK_ASSIGNER			0x00000503		// The Task object is the task assigner's copy of the Task object
+
+/* defines from [MS-OXOJRNL].pdf for journal icons */
+#define ICON_JOURNAL_CONVERSATION	0x00000601		// Conversation
+#define ICON_JOURNAL_DOCUMENT		0x00000612		// Document
+#define ICON_JOURNAL_EMAIL			0x00000602		// E-mail Message
+#define ICON_JOURNAL_FAX			0x00000609		// Fax
+#define ICON_JOURNAL_LETTER			0x0000060C		// Letter
+#define ICON_JOURNAL_MEETING		0x00000613		// Meeting
+#define ICON_JOURNAL_MEETING_CANCEL	0x00000614		// Meeting cancellation
+#define ICON_JOURNAL_MEETING_REQUEST	0x00000603		// Meeting request
+#define ICON_JOURNAL_MEETING_RESPONSE	0x00000604		// Meeting response
+#define ICON_JOURNAL_ACCESS			0x00000610		// Microsoft Office Access
+#define ICON_JOURNAL_EXCEL			0x0000060E		// Microsoft Office Excel
+#define ICON_JOURNAL_POWERPOINT		0x0000060F		// Microsoft Office PowerPoint
+#define ICON_JOURNAL_WORD			0x0000060D		// Microsoft Office Word
+#define ICON_JOURNAL_NOTE			0x00000608		// Note
+#define ICON_JOURNAL_PHONE_CALL		0x0000060A		// Phone call
+#define ICON_JOURNAL_REMOTE_SESSION	0x00000615		// Remote session
+#define ICON_JOURNAL_TASK			0x0000060B		// Task
+#define ICON_JOURNAL_TASK_REQUEST	0x00000606		// Task request
+#define ICON_JOURNAL_TASK_RESPONSE	0x00000607		// Task response
+#define ICON_JOURNAL_OTHER			0x00000003		// Other
 
 //The following properties are used in MAPI restrictions: 
 // Used when searching for attachment contents. 
@@ -446,4 +547,44 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 #define MAPI_REASON_DIRECTORY_OPERATN_FAILED  MAPI_REASON( 6 )
 #endif
 
+/* new addressbook properties */
+#define PR_DISPLAY_TYPE_EX				PROP_TAG(PT_LONG, 0x3905)
+
+/* EMSAbTag.h */
+/* 6: MV DESCRIPTION? */
+#define PR_EMS_AB_ROOM_CAPACITY			PROP_TAG(PT_LONG, 0x0807)
+/* 8: MV resource type:<>? */
+#define PR_EMS_AB_ROOM_DESCRIPTION		PROP_TAG(PT_STRING8, 0x0809)
+
+/* PR_DISPLAY_TYPE_EX values */
+/*  PR_DISPLAY_TYPEs (mapidefs.h)
+#define DT_MAILUSER         ((ULONG) 0x00000000)
+#define DT_DISTLIST         ((ULONG) 0x00000001)
+#define DT_FORUM            ((ULONG) 0x00000002)
+#define DT_AGENT            ((ULONG) 0x00000003)
+#define DT_ORGANIZATION     ((ULONG) 0x00000004)
+#define DT_PRIVATE_DISTLIST ((ULONG) 0x00000005)
+#define DT_REMOTE_MAILUSER  ((ULONG) 0x00000006)
+*/
+#define DT_ROOM	            ((ULONG) 0x00000007)
+#define DT_EQUIPMENT        ((ULONG) 0x00000008)
+#define DT_SEC_DISTLIST     ((ULONG) 0x00000009)
+
+/* PR_DISPLAY_TYPE_EX flags */
+#define DTE_FLAG_REMOTE_VALID 0x80000000 /* multiserver? */
+#define DTE_FLAG_ACL_CAPABLE  0x40000000 /* on for DT_MAILUSER and DT_SEQ_DISTLIST */
+#define DTE_MASK_REMOTE       0x0000ff00
+#define DTE_MASK_LOCAL        0x000000ff
+ 
+#define DTE_IS_REMOTE_VALID(v)	(!!((v) & DTE_FLAG_REMOTE_VALID))
+#define DTE_IS_ACL_CAPABLE(v)	(!!((v) & DTE_FLAG_ACL_CAPABLE))
+#define DTE_REMOTE(v)		(((v) & DTE_MASK_REMOTE) >> 8)
+#define DTE_LOCAL(v)		((v) & DTE_MASK_LOCAL)
+
+/* Extra ADRPARM ulFlags values */
+#define AB_UNICODEUI	0x00000040
+/* these are custom names! */
+#define AB_RESERVED1	0x00000100
+#define AB_LOCK_NON_ACL	0x00000200
+
 #endif
