@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -170,21 +172,22 @@
 #define dispidMeetingLocation				0x0002	//PT_STRING8
 #define dispidGlobalObjectID				0x0003	//PT_BINARY
 #define dispidIsRecurring					0x0005	//PT_BOOLEAN
-#define dispidMeetingRecurrenceId			0x0023	//PT_BINARY
+#define dispidCleanGlobalObjectID			0x0023	//PT_BINARY
 #define dispidMeetingMessageClass			0x0024	//PT_STRING8
-#define dispidAttendeeCriticalChange		0x1
-#define dispidOwnerCriticalChange			0x1a
-
-//Timestamp used as ID by Caldav
-#define dispidApptTsRef						0x0025	//PT_STRING8
-//FolderID used by Caldav
-#define dispidFldID							0x0026	//PT_STRING8
+#define dispidAttendeeCriticalChange		0x1		//PT_SYSTIME
+#define dispidOwnerCriticalChange			0x1a	//PT_SYSTIME
+#define dispidOldWhenStartWhole				0x0029	//PT_SYSTIME
+#define dispidIsException					0x000A	//PT_BOOLEAN
+#define dispidStartRecurrenceTime			0x000E	//PT_LONG
+#define dispidEndRecurrenceTime				0x0010	//PT_LONG
 
 //In PSETID_Zarafa_CalDav
 #define dispidMozLastAck					0x0001	//PT_SYSTIME	X-MOZ-LAST-ACK 
 #define dispidMozGen						0x0002	//PT_LONG		X-MOZ-GENERATION
 #define dispidMozSnoozeSuffixTime			0x0003	//PT_SYSTIME	X-MOZ-SNOOZE-TIME suffix 
 #define dispidMozSendInvite					0x0004	//PT_BOOLEAN	X-MOZ-SEND-INVITATIONS
+#define dispidApptTsRef						0x0025	//PT_STRING8	Timestamp used as ID by Caldav
+#define dispidFldID							0x0026	//PT_STRING8	FolderID used by Caldav
 
 // In PSETID_Common
 #define dispidReminderMinutesBeforeStart	0x8501	//PT_LONG
