@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -61,7 +63,10 @@
   #define __FD_SETSIZE 8192
 #endif
 
-  #include "config.h"
+  // Log the pthreads locks
+  #define DEBUG_PTHREADS 0
+
+  #include <config.h>
   #include "platform.linux.h"
 
 #define ZARAFA_SYSTEM_USER	"SYSTEM"
@@ -84,6 +89,7 @@ time_t SystemTimeToUnixTime(SYSTEMTIME stime);
 SYSTEMTIME UnixTimeToSystemTime(time_t unixtime);
 SYSTEMTIME TMToSystemTime(struct tm t);
 struct tm SystemTimeToTM(SYSTEMTIME stime);
+double GetTimeOfDay();
 
 inline double difftimeval(struct timeval *ptstart, struct timeval *ptend) {
 	return 1000000 * (ptend->tv_sec - ptstart->tv_sec) + (ptend->tv_usec - ptstart->tv_usec);
@@ -97,7 +103,9 @@ bool operator <(FILETIME a, FILETIME b);
 time_t operator -(FILETIME a, FILETIME b);
 
 /* convert struct tm to time_t in timezone UTC0 (GM time) */
-time_t convertGMTime(struct tm *t);
+#ifndef HAVE_TIMEGM
+time_t timegm(struct tm *t);
+#endif
 
 // mkdir -p 
 int CreatePath(const char *createpath);
