@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -70,6 +72,9 @@
 #include <byteswap.h>
 #include <endian.h>
 #endif
+#include <errno.h>
+
+#include <string>
 
 #ifdef HAVE_UNISTD_H
   #include <unistd.h>
@@ -81,6 +86,7 @@
   #include <uuid.h>
 #endif
 
+
 #ifndef DEBUG
   /* make assert() generate no code */
   #define NDEBUG
@@ -99,6 +105,7 @@
 
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <sys/times.h>
 
 /* compiler definitions */
 #define __stdcall
@@ -266,6 +273,7 @@ typedef int				SCODE;
 #define SEVERITY_ERROR		1
 #define IS_ERROR(scode)	((unsigned int)(scode) >> 31 == SEVERITY_ERROR)
 #define FAILED(scode)	((unsigned int)(scode) >> 31)
+#define SUCCEEDED(scode) (!FAILED(scode))
 
 /* from winerror.h, same as MAKE_MAPI_SCODE */
 #define MAKE_SCODE(sev,fac,code) \
@@ -605,7 +613,7 @@ void strupr(char *);
 __int64_t Int32x32To64(ULONG, ULONG);
 
 void GetSystemTimeAsFileTime(FILETIME *ft);
-
+DWORD GetTempPath(DWORD inLen, char *lpBuffer);
 int mbstounicode(WCHAR *dest, const char *src, size_t n); 
 int unicodetombs(char *dest, const WCHAR *src, size_t n);
 int unicodelen(WCHAR *src);
@@ -658,7 +666,11 @@ time_t GetProcessTime();
 
 #ifndef ntohll
 	#if __BYTE_ORDER == __LITTLE_ENDIAN
+#ifndef __OpenBSD__
 		#define ntohll(x) __bswap_64(x)
+#else
+		#define ntohll(x) __swap64(x)
+#endif // __OpenBSD__
 	#else
 		#define ntohll(x) (x)
 	#endif
@@ -666,16 +678,45 @@ time_t GetProcessTime();
 
 #ifndef htonll
 	#if __BYTE_ORDER == __LITTLE_ENDIAN
+#ifndef __OpenBSD__
 		#define htonll(x) __bswap_64(x)
+#else
+		#define htonll(x) __swap64(x)
+#endif // __OpenBSD__
 	#else
 		#define htonll(x) (x)
 	#endif
 #endif
 
 #define OutputDebugString(dstr) fprintf(stderr,"%s",dstr)
-#define GetCurrentThreadId() (int)pthread_self()
+#define GetCurrentThreadId() (long)pthread_self()
 #define GetTickCount() 0L
 
 #define TICKS_PER_SEC (sysconf(_SC_CLK_TCK))
 
+#if DEBUG_PTHREADS
+	#define pthread_mutex_lock(x) my_pthread_mutex_lock(__FILE__, __LINE__, x)
+	int my_pthread_mutex_lock(const char *file, unsigned int line, pthread_mutex_t *m);
+	
+	#define pthread_rwlock_rdlock(x) my_pthread_rwlock_rdlock(__FILE__, __LINE__, x)
+	int my_pthread_rwlock_rdlock(const char *file, unsigned int line, pthread_rwlock_t *m);
+	
+	#define pthread_rwlock_wrlock(x) my_pthread_rwlock_wrlock(__FILE__, __LINE__, x)
+	int my_pthread_rwlock_wrlock(const char *file, unsigned int line, pthread_rwlock_t *m);
+
+	std::string dump_pthread_locks();
+#endif
+
+
+
+#define createlocale(_cat, _loc) newlocale(_cat ## _MASK, _loc, NULL)
+
+/**
+ * Tell the compiler that a funtion/method behaves like printf.
+ * _fmt is the 1-indexed index to the format argument
+ * _va is the 1-indexed index to the first va argument.
+ * NOTE: For non-static methods the this pointer has index 1.
+ **/
+#define __LIKE_PRINTF(_fmt, _va) __attribute__((format(printf, _fmt, _va)))
+
 #endif // PLATFORM_LINUX_H
