@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -59,6 +61,13 @@
 		goto exit; \
 	}
 
+#define CREATE_RESTRICTION_BASE(_lpBase, _lpRestriction) \
+	{\
+	hr = MAPIAllocateMore(sizeof(SRestriction), _lpBase, (LPVOID*)&(_lpRestriction)); \
+	if (hr != hrSuccess) \
+		goto exit; \
+	}
+
 #define FREE_RESTRICTION(_lpRestriction) \
 	{\
 	if (_lpRestriction) {\
@@ -74,15 +83,15 @@
 		goto exit; \
 	} \
 \
-	_lpRestriction->rt = RES_AND; \
+	(_lpRestriction)->rt = RES_AND; \
 \
-	hr = MAPIAllocateMore(sizeof(SRestriction) * _values, _lpBase, (void**)&(_lpRestriction->res.resAnd.lpRes)); \
+	hr = MAPIAllocateMore(sizeof(SRestriction) * _values, _lpBase, (void**)&((_lpRestriction)->res.resAnd.lpRes)); \
 	if (hr != hrSuccess) { \
 		hr = MAPI_E_INVALID_PARAMETER; \
 		goto exit; \
 	} \
 \
-	_lpRestriction->res.resAnd.cRes = _values; \
+	(_lpRestriction)->res.resAnd.cRes = _values; \
 	}
 
 #define CREATE_RES_OR(_lpBase, _lpRestriction, _values) \
@@ -92,15 +101,15 @@
 		goto exit; \
 	} \
 \
-	_lpRestriction->rt = RES_OR; \
+	(_lpRestriction)->rt = RES_OR; \
 \
-	hr = MAPIAllocateMore(sizeof(SRestriction) * _values, _lpBase, (void**)&(_lpRestriction->res.resOr.lpRes)); \
+	hr = MAPIAllocateMore(sizeof(SRestriction) * _values, _lpBase, (void**)&((_lpRestriction)->res.resOr.lpRes)); \
 	if (hr != hrSuccess) { \
 		hr = MAPI_E_INVALID_PARAMETER; \
 		goto exit; \
 	} \
 \
-	_lpRestriction->res.resOr.cRes = _values; \
+	(_lpRestriction)->res.resOr.cRes = _values; \
 	}
 
 #define CREATE_RES_NOT(_lpBase, _lpRestriction) \
@@ -110,62 +119,88 @@
 		goto exit; \
 	} \
 \
-	_lpRestriction->rt = RES_NOT; \
+	(_lpRestriction)->rt = RES_NOT; \
 \
-	hr = MAPIAllocateMore(sizeof(SRestriction), _lpBase, (void**)&(_lpRestriction->res.resNot.lpRes)); \
+	hr = MAPIAllocateMore(sizeof(SRestriction), _lpBase, (void**)&((_lpRestriction)->res.resNot.lpRes)); \
 	if (hr != hrSuccess) { \
 		hr = MAPI_E_INVALID_PARAMETER; \
 		goto exit; \
 	} \
 \
-	_lpRestriction->res.resNot.ulReserved = 0; \
+	(_lpRestriction)->res.resNot.ulReserved = 0; \
 }
 
 
 #define DATA_RES_PROPERTY(_lpBase, _sRestriction, _ulRelop, _ulPropTag, _lpProp) \
 	{\
-	_sRestriction.rt = RES_PROPERTY; \
-	_sRestriction.res.resProperty.relop = _ulRelop; \
-	_sRestriction.res.resProperty.ulPropTag = _ulPropTag; \
+	(_sRestriction).rt = RES_PROPERTY; \
+	(_sRestriction).res.resProperty.relop = _ulRelop; \
+	(_sRestriction).res.resProperty.ulPropTag = _ulPropTag; \
 \
-	hr = MAPIAllocateMore(sizeof(SPropValue), _lpBase, (void**)&_sRestriction.res.resProperty.lpProp);\
+	hr = MAPIAllocateMore(sizeof(SPropValue), _lpBase, (void**)&(_sRestriction).res.resProperty.lpProp);\
 	if(hr != hrSuccess) \
 		goto exit; \
-	hr = Util::HrCopyProperty(_sRestriction.res.resProperty.lpProp, _lpProp, _lpBase);\
+	hr = Util::HrCopyProperty((_sRestriction).res.resProperty.lpProp, _lpProp, _lpBase);\
 	if(hr != hrSuccess) \
 		goto exit; \
-	_sRestriction.res.resProperty.lpProp->ulPropTag = _ulPropTag; \
+	(_sRestriction).res.resProperty.lpProp->ulPropTag = _ulPropTag; \
+	}
+
+#define DATA_RES_PROPERTY_CHEAP(_lpBase, _sRestriction, _ulRelop, _ulPropTag, _lpProp) \
+	{\
+	(_sRestriction).rt = RES_PROPERTY; \
+	(_sRestriction).res.resProperty.relop = _ulRelop; \
+	(_sRestriction).res.resProperty.ulPropTag = _ulPropTag; \
+	(_sRestriction).res.resProperty.lpProp = _lpProp; \
+	(_sRestriction).res.resProperty.lpProp->ulPropTag = _ulPropTag; \
 	}
 
 #define  DATA_RES_EXIST(_lpBase, _sRestriction, _ulPropTag) \
 	{\
-	_sRestriction.rt = RES_EXIST; \
-	_sRestriction.res.resExist.ulReserved1 = 0; \
-	_sRestriction.res.resExist.ulPropTag = _ulPropTag; \
-	_sRestriction.res.resExist.ulReserved2 = 0; \
+	(_sRestriction).rt = RES_EXIST; \
+	(_sRestriction).res.resExist.ulReserved1 = 0; \
+	(_sRestriction).res.resExist.ulPropTag = _ulPropTag; \
+	(_sRestriction).res.resExist.ulReserved2 = 0; \
+	}
+
+#define  DATA_RES_COMPAREPROPS(_lpBase, _sRestriction, _relop, _ulPropTag1, _ulPropTag2) \
+	{\
+	(_sRestriction).rt = RES_COMPAREPROPS; \
+	(_sRestriction).res.resCompareProps.relop = _relop; \
+	(_sRestriction).res.resCompareProps.ulPropTag1 = _ulPropTag1; \
+	(_sRestriction).res.resCompareProps.ulPropTag2 = _ulPropTag2; \
 	}
 
 #define  DATA_RES_BITMASK(_lpBase, _sRestriction, _relBMR, _ulPropTag, _ulMask) \
 	{\
-	_sRestriction.rt = RES_BITMASK; \
-	_sRestriction.res.resBitMask.relBMR = _relBMR; \
-	_sRestriction.res.resBitMask.ulPropTag = _ulPropTag; \
-	_sRestriction.res.resBitMask.ulMask = _ulMask; \
+	(_sRestriction).rt = RES_BITMASK; \
+	(_sRestriction).res.resBitMask.relBMR = _relBMR; \
+	(_sRestriction).res.resBitMask.ulPropTag = _ulPropTag; \
+	(_sRestriction).res.resBitMask.ulMask = _ulMask; \
 	}
 
 #define DATA_RES_CONTENT(_lpBase, _sRestriction, _ulFuzzyLevel, _ulPropTag, _lpProp) \
 	{\
-	_sRestriction.rt = RES_CONTENT; \
-	_sRestriction.res.resContent.ulFuzzyLevel = _ulFuzzyLevel; \
-	_sRestriction.res.resContent.ulPropTag = _ulPropTag; \
+	(_sRestriction).rt = RES_CONTENT; \
+	(_sRestriction).res.resContent.ulFuzzyLevel = _ulFuzzyLevel; \
+	(_sRestriction).res.resContent.ulPropTag = _ulPropTag; \
 \
-	hr = MAPIAllocateMore(sizeof(SPropValue), _lpBase, (void**)&_sRestriction.res.resContent.lpProp);\
+	hr = MAPIAllocateMore(sizeof(SPropValue), _lpBase, (void**)&(_sRestriction).res.resContent.lpProp);\
 	if(hr != hrSuccess) \
 		goto exit; \
-	hr = Util::HrCopyProperty(_sRestriction.res.resContent.lpProp, _lpProp, _lpBase);\
+	hr = Util::HrCopyProperty((_sRestriction).res.resContent.lpProp, _lpProp, _lpBase);\
 	if(hr != hrSuccess) \
 		goto exit; \
-	_sRestriction.res.resContent.lpProp->ulPropTag = _ulPropTag; \
+	(_sRestriction).res.resContent.lpProp->ulPropTag = _ulPropTag; \
+	}
+
+#define DATA_RES_CONTENT_CHEAP(_lpBase, _sRestriction, _ulFuzzyLevel, _ulPropTag, _lpProp) \
+	{\
+	(_sRestriction).rt = RES_CONTENT; \
+	(_sRestriction).res.resContent.ulFuzzyLevel = _ulFuzzyLevel; \
+	(_sRestriction).res.resContent.ulPropTag = _ulPropTag; \
+	(_sRestriction).res.resContent.lpProp = _lpProp; \
+	(_sRestriction).res.resContent.lpProp->ulPropTag = _ulPropTag; \
 	}
 
 
