@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -73,6 +75,9 @@ static inline std::string strToLower(std::string f) {
 	return f;
 }
 
+std::wstring towstring(const std::string &s);
+std::string tostring(const std::wstring &ws);
+
 // Use casting if passing hard coded values.
 std::string stringify(unsigned int x, bool usehex = false);
 std::string stringify_int64(long long x, bool usehex = false);
@@ -80,9 +85,14 @@ std::string stringify_float(float x);
 std::string stringify_double(double x, int prec = 18);
 std::string stringify_datetime(time_t x);
 
-inline unsigned int	atoui(char *szString) { return strtoul(szString, NULL, 10); }
+std::wstring wstringify(unsigned int x, bool usehex = false);
+std::wstring wstringify_int64(long long x, bool usehex = false);
+std::wstring wstringify_uint64(unsigned long long x, bool usehex = false);
+std::wstring wstringify_float(float x);
+std::wstring wstringify_double(double x, int prec = 18);
 
-char* stristr(char *haystack, char *needle);
+inline unsigned int	atoui(const char *szString) { return strtoul(szString, NULL, 10); }
+unsigned int xtoi(const char *lpszHex);
 
 int memsubstr(const void* haystack, size_t haystackSize, const void* needle, size_t needleSize);
 
@@ -91,6 +101,10 @@ std::string striconv(const std::string &strinput, const char *lpszFromCharset, c
 std::string str_storage(unsigned long long ulBytes, bool bUnlimited = true);
 
 std::string PrettyIP(long unsigned int ip);
+std::string GetServerNameFromPath(const char *szPath);
+std::string GetServerTypeFromPath(const char *szPath);
+std::string GetServerPortFromPath(const char *szPath);
+std::string ServerNamePortToURL(const char *lpszType, const char *lpszServerName, const char *lpszServerPort, const char *lpszExtra = "zarafa");
 
 static inline bool parseBool(const std::string &s) {
 	return !(s == "0" || s == "false" || s == "no");
@@ -102,8 +116,15 @@ std::string shell_escape(std::string str);
 
 std::vector<std::string> tokenize(const char *input, const char sep);
 std::vector<std::string> tokenize(const std::string &strInput, const std::string &strSep);
+std::string concatenate(std::vector<std::string> &elements, const std::string &delimeters);
 
-std::string trim(const std::string &strInput);
+std::string trim(const std::string &strInput, const std::string &strTrim = " ");
+
+unsigned char x2b(char c);
+std::string hex2bin(const std::string &input);
+std::string bin2hex(unsigned int inLength, const unsigned char *input);
+
+std::string StringEscape(const char* input, const char *tokens, const char escape);
 
 std::string strUnEscapeHex(std::string strIn);
 
